@@ -6,8 +6,7 @@ import click
 from great_expectations import DataContext
 from great_expectations import exceptions as ge_exceptions
 from great_expectations.cli import toolkit
-from great_expectations.cli.datasource import \
-    add_datasource as add_datasource_impl
+from great_expectations.cli.datasource import add_datasource as add_datasource_impl
 from great_expectations.cli.docs import build_docs
 from great_expectations.cli.init_messages import (
     BUILD_DOCS_PROMPT,
@@ -24,15 +23,12 @@ from great_expectations.cli.init_messages import (
     SLACK_WEBHOOK_PROMPT,
 )
 from great_expectations.cli.util import cli_message, is_sane_slack_webhook
+from great_expectations.core.usage_statistics.usage_statistics import send_usage_message
 from great_expectations.exceptions import (
     DataContextError,
     DatasourceInitializationError,
 )
 
-from great_expectations.core.usage_statistics.usage_statistics import (
-    send_usage_message,
-)
-
 try:
     from sqlalchemy.exc import SQLAlchemyError
 except ImportError:
@@ -57,7 +53,7 @@ except ImportError:
 @click.option(
     "--usage-stats/--no-usage-stats",
     help="By default, usage statistics are enabled unless you specify the --no-usage-stats flag.",
-    default=True
+    default=True,
 )
 def init(target_directory, view, usage_stats):
     """
@@ -83,7 +79,9 @@ def init(target_directory, view, usage_stats):
             sys.exit(1)
 
         try:
-            context = DataContext.create(target_directory, usage_statistics_enabled=usage_stats)
+            context = DataContext.create(
+                target_directory, usage_statistics_enabled=usage_stats
+            )
             cli_message(ONBOARDING_COMPLETE)
             # TODO if this is correct, ensure this is covered by a test
             # cli_message(SETUP_SUCCESS)
@@ -99,8 +97,12 @@ def init(target_directory, view, usage_stats):
             exit(0)
 
         try:
-            context = DataContext.create(target_directory, usage_statistics_enabled=usage_stats)
-            send_usage_message(data_context=context, event="cli.init.create", success=True)
+            context = DataContext.create(
+                target_directory, usage_statistics_enabled=usage_stats
+            )
+            send_usage_message(
+                data_context=context, event="cli.init.create", success=True
+            )
         except DataContextError as e:
             # TODO ensure this is covered by a test
             cli_message("<red>{}</red>".format(e))
@@ -115,7 +117,9 @@ def init(target_directory, view, usage_stats):
         else:
             datasources = context.list_datasources()
             if len(datasources) == 0:
-                datasource_name, data_source_type = add_datasource_impl(context, choose_one_data_asset=True)
+                datasource_name, data_source_type = add_datasource_impl(
+                    context, choose_one_data_asset=True
+                )
                 if not datasource_name:  # no datasource was created
                     sys.exit(1)
 
@@ -123,12 +127,17 @@ def init(target_directory, view, usage_stats):
             if len(datasources) == 1:
                 datasource_name = datasources[0]["name"]
 
-                success, suite_name = toolkit.create_expectation_suite(context, datasource_name=datasource_name,
-                                                                    additional_batch_kwargs={"limit": 1000},
-                                                                    open_docs=view)
+                success, suite_name = toolkit.create_expectation_suite(
+                    context,
+                    datasource_name=datasource_name,
+                    additional_batch_kwargs={"limit": 1000},
+                    open_docs=view,
+                )
                 if success:
                     cli_message(
-                        "A new Expectation suite '{}' was added to your project".format(suite_name)
+                        "A new Expectation suite '{}' was added to your project".format(
+                            suite_name
+                        )
                     )
 
                 cli_message(SETUP_SUCCESS)
@@ -137,7 +146,7 @@ def init(target_directory, view, usage_stats):
         DataContextError,
         ge_exceptions.ProfilerError,
         IOError,
-        SQLAlchemyError
+        SQLAlchemyError,
     ) as e:
         cli_message("<red>{}</red>".format(e))
         sys.exit(1)
