@@ -21,7 +21,7 @@ class BatchKwargsAnonymizer(Anonymizer):
             "query_parameters",
             "offset",
             "snowflake_transient_table",
-            "bigquery_temp_table"
+            "bigquery_temp_table",
         ]
 
     def anonymize_batch_kwargs(self, batch_kwargs):
@@ -32,4 +32,4 @@ class BatchKwargsAnonymizer(Anonymizer):
             else:
                 anonymized_batch_kwarg_keys.append(self.anonymize(batch_kwarg_key))
 
-        return anonymized_batch_kwarg_keys
\ No newline at end of file
+        return anonymized_batch_kwarg_keys
