@@ -1,8 +1,16 @@
+import logging
 import uuid
 from copy import deepcopy
-import logging
 
-from marshmallow import Schema, fields, ValidationError, INCLUDE, post_load, validates_schema, post_dump
+from marshmallow import (
+    INCLUDE,
+    Schema,
+    ValidationError,
+    fields,
+    post_dump,
+    post_load,
+    validates_schema,
+)
 from ruamel.yaml import YAML
 from ruamel.yaml.comments import CommentedMap
 
@@ -16,24 +24,26 @@ yaml = YAML()
 
 CURRENT_CONFIG_VERSION = 1
 MINIMUM_SUPPORTED_CONFIG_VERSION = 1
-DEFAULT_USAGE_STATISTICS_URL = "https://stats.greatexpectations.io/great_expectations/v1/usage_statistics"
+DEFAULT_USAGE_STATISTICS_URL = (
+    "https://stats.greatexpectations.io/great_expectations/v1/usage_statistics"
+)
 
 
 class DataContextConfig(DictDot):
     def __init__(
-            self,
-            config_version,
-            datasources,
-            expectations_store_name,
-            validations_store_name,
-            evaluation_parameter_store_name,
-            plugins_directory,
-            validation_operators,
-            stores,
-            data_docs_sites,
-            config_variables_file_path=None,
-            anonymous_usage_statistics=None,
-            commented_map=None
+        self,
+        config_version,
+        datasources,
+        expectations_store_name,
+        validations_store_name,
+        evaluation_parameter_store_name,
+        plugins_directory,
+        validation_operators,
+        stores,
+        data_docs_sites,
+        config_variables_file_path=None,
+        anonymous_usage_statistics=None,
+        commented_map=None,
     ):
         if commented_map is None:
             commented_map = CommentedMap()
@@ -47,7 +57,9 @@ class DataContextConfig(DictDot):
         self.evaluation_parameter_store_name = evaluation_parameter_store_name
         self.plugins_directory = plugins_directory
         if not isinstance(validation_operators, dict):
-            raise ValueError("validation_operators must be configured with a dictionary")
+            raise ValueError(
+                "validation_operators must be configured with a dictionary"
+            )
         self.validation_operators = validation_operators
         self.stores = stores
         self.data_docs_sites = data_docs_sites
@@ -55,7 +67,9 @@ class DataContextConfig(DictDot):
         if anonymous_usage_statistics is None:
             anonymous_usage_statistics = AnonymizedUsageStatisticsConfig()
         elif isinstance(anonymous_usage_statistics, dict):
-            anonymous_usage_statistics = AnonymizedUsageStatisticsConfig(**anonymous_usage_statistics)
+            anonymous_usage_statistics = AnonymizedUsageStatisticsConfig(
+                **anonymous_usage_statistics
+            )
         self.anonymous_usage_statistics = anonymous_usage_statistics
 
     @property
@@ -72,7 +86,9 @@ class DataContextConfig(DictDot):
             config = dataContextConfigSchema.load(commented_map)
             return cls(commented_map=commented_map, **config)
         except ValidationError:
-            logger.error("Encountered errors during loading data context config. See ValidationError for more details.")
+            logger.error(
+                "Encountered errors during loading data context config. See ValidationError for more details."
+            )
             raise
 
     def to_yaml(self, outfile):
@@ -82,8 +98,17 @@ class DataContextConfig(DictDot):
 
 
 class DatasourceConfig(DictDot):
-    def __init__(self, class_name, module_name=None, data_asset_type=None, batch_kwargs_generators=None, credentials=None,
-                 reader_method=None, limit=None, **kwargs):
+    def __init__(
+        self,
+        class_name,
+        module_name=None,
+        data_asset_type=None,
+        batch_kwargs_generators=None,
+        credentials=None,
+        reader_method=None,
+        limit=None,
+        **kwargs
+    ):
         # NOTE - JPC - 20200316: Currently, we are mostly inconsistent with respect to this type...
         self._class_name = class_name
         self._module_name = module_name
@@ -144,7 +169,9 @@ class AnonymizedUsageStatisticsConfig(DictDot):
         try:
             uuid.UUID(data_context_id)
         except ValueError:
-            raise ge_exceptions.InvalidConfigError("data_context_id must be a valid uuid")
+            raise ge_exceptions.InvalidConfigError(
+                "data_context_id must be a valid uuid"
+            )
         self._data_context_id = data_context_id
         self._explicit_id = True
 
@@ -194,12 +221,14 @@ class DatasourceConfigSchema(Schema):
     data_asset_type = fields.Nested(ClassConfigSchema)
     # TODO: Update to generator-specific
     # batch_kwargs_generators = fields.Mapping(keys=fields.Str(), values=fields.Nested(fields.GeneratorSchema))
-    batch_kwargs_generators = fields.Dict(keys=fields.Str(), values=fields.Dict(), allow_none=True)
+    batch_kwargs_generators = fields.Dict(
+        keys=fields.Str(), values=fields.Dict(), allow_none=True
+    )
     credentials = fields.Raw(allow_none=True)
 
     @validates_schema
     def validate_schema(self, data, **kwargs):
-        if 'generators' in data:
+        if "generators" in data:
             raise ge_exceptions.InvalidConfigError(
                 "Your current configuration uses the 'generators' key in a datasource, but in version 0.10 of "
                 "GE, that key is renamed to 'batch_kwargs_generators'. Please update your config to continue."
@@ -212,16 +241,22 @@ class DatasourceConfigSchema(Schema):
 
 
 class DataContextConfigSchema(Schema):
-    config_version = fields.Number(validate=lambda x: 0 < x < 100, error_messages={"invalid": "config version must "
-                                                                                              "be a number."})
-    datasources = fields.Dict(keys=fields.Str(), values=fields.Nested(DatasourceConfigSchema))
+    config_version = fields.Number(
+        validate=lambda x: 0 < x < 100,
+        error_messages={"invalid": "config version must " "be a number."},
+    )
+    datasources = fields.Dict(
+        keys=fields.Str(), values=fields.Nested(DatasourceConfigSchema)
+    )
     expectations_store_name = fields.Str()
     validations_store_name = fields.Str()
     evaluation_parameter_store_name = fields.Str()
     plugins_directory = fields.Str(allow_none=True)
     validation_operators = fields.Dict(keys=fields.Str(), values=fields.Dict())
     stores = fields.Dict(keys=fields.Str(), values=fields.Dict())
-    data_docs_sites = fields.Dict(keys=fields.Str(), values=fields.Dict(), allow_none=True)
+    data_docs_sites = fields.Dict(
+        keys=fields.Str(), values=fields.Dict(), allow_none=True
+    )
     config_variables_file_path = fields.Str(allow_none=True)
     anonymous_usage_statistics = fields.Nested(AnonymizedUsageStatisticsConfigSchema)
 
@@ -230,43 +265,46 @@ class DataContextConfigSchema(Schema):
     def handle_error(self, exc, data, **kwargs):
         """Log and raise our custom exception when (de)serialization fails."""
         logger.error(exc.messages)
-        raise ge_exceptions.InvalidDataContextConfigError("Error while processing DataContextConfig.",
-                                                          exc)
+        raise ge_exceptions.InvalidDataContextConfigError(
+            "Error while processing DataContextConfig.", exc
+        )
 
     @validates_schema
     def validate_schema(self, data, **kwargs):
-        if 'config_version' not in data:
+        if "config_version" not in data:
             raise ge_exceptions.InvalidDataContextConfigError(
                 "The key `config_version` is missing; please check your config file.",
-                validation_error=ValidationError("no config_version key"))
+                validation_error=ValidationError("no config_version key"),
+            )
 
-        if not isinstance(data['config_version'], (int, float)):
+        if not isinstance(data["config_version"], (int, float)):
             raise ge_exceptions.InvalidDataContextConfigError(
                 "The key `config_version` must be a number. Please check your config file.",
-                validation_error=ValidationError("config version not a number")
+                validation_error=ValidationError("config version not a number"),
             )
 
         # When migrating from 0.7.x to 0.8.0
-        if data['config_version'] == 0 and (
-                "validations_store" in list(data.keys()) or "validations_stores" in list(data.keys())):
+        if data["config_version"] == 0 and (
+            "validations_store" in list(data.keys())
+            or "validations_stores" in list(data.keys())
+        ):
             raise ge_exceptions.UnsupportedConfigVersionError(
                 "You appear to be using a config version from the 0.7.x series. This version is no longer supported."
             )
-        elif data['config_version'] < MINIMUM_SUPPORTED_CONFIG_VERSION:
+        elif data["config_version"] < MINIMUM_SUPPORTED_CONFIG_VERSION:
             raise ge_exceptions.UnsupportedConfigVersionError(
                 "You appear to have an invalid config version ({}).\n    The version number must be between {} and {}.".format(
-                    data['config_version'],
+                    data["config_version"],
                     MINIMUM_SUPPORTED_CONFIG_VERSION,
                     CURRENT_CONFIG_VERSION,
                 ),
             )
-        elif data['config_version'] > CURRENT_CONFIG_VERSION:
+        elif data["config_version"] > CURRENT_CONFIG_VERSION:
             raise ge_exceptions.InvalidDataContextConfigError(
                 "You appear to have an invalid config version ({}).\n    The maximum valid version is {}.".format(
-                    data['config_version'],
-                    CURRENT_CONFIG_VERSION
+                    data["config_version"], CURRENT_CONFIG_VERSION
                 ),
-                validation_error=ValidationError("config version too high")
+                validation_error=ValidationError("config version too high"),
             )
 
 
