@@ -43,9 +43,7 @@ class DatasetProfiler(DataAssetProfiler):
 
     @classmethod
     def add_expectation_meta(cls, expectation):
-        expectation.meta[str(cls.__name__)] = {
-            "confidence": "very low"
-        }
+        expectation.meta[str(cls.__name__)] = {"confidence": "very low"}
         return expectation
 
     @classmethod
@@ -59,8 +57,9 @@ class DatasetProfiler(DataAssetProfiler):
         if batch_kwargs is not None:
             expectation_suite.meta[class_name]["batch_kwargs"] = batch_kwargs
 
-        new_expectations = [cls.add_expectation_meta(
-            exp) for exp in expectation_suite.expectations]
+        new_expectations = [
+            cls.add_expectation_meta(exp) for exp in expectation_suite.expectations
+        ]
         expectation_suite.expectations = new_expectations
 
         if "notes" not in expectation_suite.meta:
@@ -68,10 +67,10 @@ class DatasetProfiler(DataAssetProfiler):
                 "format": "markdown",
                 "content": [
                     "_To add additional notes, edit the <code>meta.notes.content</code> field in the appropriate Expectation json file._"
-                    #TODO: be more helpful to the user by piping in the filename.
-                    #This will require a minor refactor to make more DataContext information accessible from this method.
+                    # TODO: be more helpful to the user by piping in the filename.
+                    # This will require a minor refactor to make more DataContext information accessible from this method.
                     # "_To add additional notes, edit the <code>meta.notes.content</code> field in <code>expectations/mydb/default/movies/BasicDatasetProfiler.json</code>_"
-                ]
+                ],
             }
         return expectation_suite
 
@@ -80,16 +79,20 @@ class DatasetProfiler(DataAssetProfiler):
         if not cls.validate(data_asset):
             raise GreatExpectationsError("Invalid data_asset for profiler; aborting")
 
-        expectation_suite = cls._profile(data_asset, configuration=profiler_configuration)
+        expectation_suite = cls._profile(
+            data_asset, configuration=profiler_configuration
+        )
 
         batch_kwargs = data_asset.batch_kwargs
         expectation_suite = cls.add_meta(expectation_suite, batch_kwargs)
-        validation_results = data_asset.validate(expectation_suite, run_id=run_id, result_format="SUMMARY")
+        validation_results = data_asset.validate(
+            expectation_suite, run_id=run_id, result_format="SUMMARY"
+        )
         expectation_suite.add_citation(
             comment=str(cls.__name__) + " added a citation based on the current batch.",
             batch_kwargs=data_asset.batch_kwargs,
             batch_markers=data_asset.batch_markers,
-            batch_parameters=data_asset.batch_parameters
+            batch_parameters=data_asset.batch_parameters,
         )
         return expectation_suite, validation_results
 
